==> istio-model-v1beta1-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPMatchRequestFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPMatchRequestFluent<A extends HTTPMatchRequestFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAuthority instead.
   * @return The buildable object.
   */
  @Deprecated
  public StringMatch getAuthority();
  public StringMatch buildAuthority();
  public A withAuthority(StringMatch authority);
  public Boolean hasAuthority();
  public HTTPMatchRequestFluent.AuthorityNested<A> withNewAuthority();
  public HTTPMatchRequestFluent.AuthorityNested<A> withNewAuthorityLike(StringMatch item);
  public HTTPMatchRequestFluent.AuthorityNested<A> editAuthority();
  public HTTPMatchRequestFluent.AuthorityNested<A> editOrNewAuthority();
  public HTTPMatchRequestFluent.AuthorityNested<A> editOrNewAuthorityLike(StringMatch item);
  public A addToGateways(Integer index,String item);
  public A setToGateways(Integer index,String item);
  public A addToGateways(java.lang.String... items);
  public A addAllToGateways(Collection<String> items);
  public A removeFromGateways(java.lang.String... items);
  public A removeAllFromGateways(Collection<String> items);
  public List<String> getGateways();
  public String getGateway(Integer index);
  public String getFirstGateway();
  public String getLastGateway();
  public String getMatchingGateway(Predicate<String> predicate);
  public Boolean hasMatchingGateway(Predicate<String> predicate);
  public A withGateways(List<String> gateways);
  public A withGateways(java.lang.String... gateways);
  public Boolean hasGateways();
  public A addToHeaders(String key,StringMatch value);
  public A addToHeaders(Map<String,StringMatch> map);
  public A removeFromHeaders(String key);
  public A removeFromHeaders(Map<String,StringMatch> map);
  public Map<String,StringMatch> getHeaders();
  public <K,V>A withHeaders(Map<String,StringMatch> headers);
  public Boolean hasHeaders();
  public Boolean getIgnoreUriCase();
  public A withIgnoreUriCase(Boolean ignoreUriCase);
  public Boolean hasIgnoreUriCase();
  
  /**
   * This method has been deprecated, please use method buildMethod instead.
   * @return The buildable object.
   */
  @Deprecated
  public StringMatch getMethod();
  public StringMatch buildMethod();
  public A withMethod(StringMatch method);
  public Boolean hasMethod();
  public HTTPMatchRequestFluent.MethodNested<A> withNewMethod();
  public HTTPMatchRequestFluent.MethodNested<A> withNewMethodLike(StringMatch item);
  public HTTPMatchRequestFluent.MethodNested<A> editMethod();
  public HTTPMatchRequestFluent.MethodNested<A> editOrNewMethod();
  public HTTPMatchRequestFluent.MethodNested<A> editOrNewMethodLike(StringMatch item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public A addToQueryParams(String key,StringMatch value);
  public A addToQueryParams(Map<String,StringMatch> map);
  public A removeFromQueryParams(String key);
  public A removeFromQueryParams(Map<String,StringMatch> map);
  public Map<String,StringMatch> getQueryParams();
  public <K,V>A withQueryParams(Map<String,StringMatch> queryParams);
  public Boolean hasQueryParams();
  
  /**
   * This method has been deprecated, please use method buildScheme instead.
   * @return The buildable object.
   */
  @Deprecated
  public StringMatch getScheme();
  public StringMatch buildScheme();
  public A withScheme(StringMatch scheme);
  public Boolean hasScheme();
  public HTTPMatchRequestFluent.SchemeNested<A> withNewScheme();
  public HTTPMatchRequestFluent.SchemeNested<A> withNewSchemeLike(StringMatch item);
  public HTTPMatchRequestFluent.SchemeNested<A> editScheme();
  public HTTPMatchRequestFluent.SchemeNested<A> editOrNewScheme();
  public HTTPMatchRequestFluent.SchemeNested<A> editOrNewSchemeLike(StringMatch item);
  public A addToSourceLabels(String key,String value);
  public A addToSourceLabels(Map<String,String> map);
  public A removeFromSourceLabels(String key);
  public A removeFromSourceLabels(Map<String,String> map);
  public Map<String,String> getSourceLabels();
  public <K,V>A withSourceLabels(Map<String,String> sourceLabels);
  public Boolean hasSourceLabels();
  public String getSourceNamespace();
  public A withSourceNamespace(String sourceNamespace);
  public Boolean hasSourceNamespace();
  
  /**
   * This method has been deprecated, please use method buildUri instead.
   * @return The buildable object.
   */
  @Deprecated
  public StringMatch getUri();
  public StringMatch buildUri();
  public A withUri(StringMatch uri);
  public Boolean hasUri();
  public HTTPMatchRequestFluent.UriNested<A> withNewUri();
  public HTTPMatchRequestFluent.UriNested<A> withNewUriLike(StringMatch item);
  public HTTPMatchRequestFluent.UriNested<A> editUri();
  public HTTPMatchRequestFluent.UriNested<A> editOrNewUri();
  public HTTPMatchRequestFluent.UriNested<A> editOrNewUriLike(StringMatch item);
  public A addToWithoutHeaders(String key,StringMatch value);
  public A addToWithoutHeaders(Map<String,StringMatch> map);
  public A removeFromWithoutHeaders(String key);
  public A removeFromWithoutHeaders(Map<String,StringMatch> map);
  public Map<String,StringMatch> getWithoutHeaders();
  public <K,V>A withWithoutHeaders(Map<String,StringMatch> withoutHeaders);
  public Boolean hasWithoutHeaders();
  public A withIgnoreUriCase();
  public interface AuthorityNested<N> extends Nested<N>,StringMatchFluent<HTTPMatchRequestFluent.AuthorityNested<N>>{
    public N and();
    public N endAuthority();
    
  }
  public interface MethodNested<N> extends Nested<N>,StringMatchFluent<HTTPMatchRequestFluent.MethodNested<N>>{
    public N and();
    public N endMethod();
    
  }
  public interface SchemeNested<N> extends Nested<N>,StringMatchFluent<HTTPMatchRequestFluent.SchemeNested<N>>{
    public N and();
    public N endScheme();
    
  }
  public interface UriNested<N> extends Nested<N>,StringMatchFluent<HTTPMatchRequestFluent.UriNested<N>>{
    public N and();
    public N endUri();
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPMatchRequestFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPMatchRequestFluent<A extends HTTPMatchRequestFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAuthority instead.
   * @return The buildable object.
   */
  @Deprecated
  public StringMatch getAuthority();
  public StringMatch buildAuthority();
  public A withAuthority(StringMatch authority);
  public Boolean hasAuthority();
  public HTTPMatchRequestFluent.AuthorityNested<A> withNewAuthority();
  public HTTPMatchRequestFluent.AuthorityNested<A> withNewAuthorityLike(StringMatch item);
  public HTTPMatchRequestFluent.AuthorityNested<A> editAuthority();
  public HTTPMatchRequestFluent.AuthorityNested<A> editOrNewAuthority();
  public HTTPMatchRequestFluent.AuthorityNested<A> editOrNewAuthorityLike(StringMatch item);
  public A addToGateways(int index,String item);
  public A setToGateways(int index,String item);
  public A addToGateways(java.lang.String... items);
  public A addAllToGateways(Collection<String> items);
  public A removeFromGateways(java.lang.String... items);
  public A removeAllFromGateways(Collection<String> items);
  public List<String> getGateways();
  public String getGateway(int index);
  public String getFirstGateway();
  public String getLastGateway();
  public String getMatchingGateway(Predicate<String> predicate);
  public Boolean hasMatchingGateway(Predicate<String> predicate);
  public A withGateways(List<String> gateways);
  public A withGateways(java.lang.String... gateways);
  public Boolean hasGateways();
  public A addToHeaders(String key,StringMatch value);
  public A addToHeaders(Map<String,StringMatch> map);
  public A removeFromHeaders(String key);
  public A removeFromHeaders(Map<String,StringMatch> map);
  public Map<String,StringMatch> getHeaders();
  public <K,V>A withHeaders(Map<String,StringMatch> headers);
  public Boolean hasHeaders();
  public Boolean getIgnoreUriCase();
  public A withIgnoreUriCase(Boolean ignoreUriCase);
  public Boolean hasIgnoreUriCase();
  
  /**
   * This method has been deprecated, please use method buildMethod instead.
   * @return The buildable object.
   */
  @Deprecated
  public StringMatch getMethod();
  public StringMatch buildMethod();
  public A withMethod(StringMatch method);
  public Boolean hasMethod();
  public HTTPMatchRequestFluent.MethodNested<A> withNewMethod();
  public HTTPMatchRequestFluent.MethodNested<A> withNewMethodLike(StringMatch item);
  public HTTPMatchRequestFluent.MethodNested<A> editMethod();
  public HTTPMatchRequestFluent.MethodNested<A> editOrNewMethod();
  public HTTPMatchRequestFluent.MethodNested<A> editOrNewMethodLike(StringMatch item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public A addToQueryParams(String key,StringMatch value);
  public A addToQueryParams(Map<String,StringMatch> map);
  public A removeFromQueryParams(String key);
  public A removeFromQueryParams(Map<String,StringMatch> map);
  public Map<String,StringMatch> getQueryParams();
  public <K,V>A withQueryParams(Map<String,StringMatch> queryParams);
  public Boolean hasQueryParams();
  
  /**
   * This method has been deprecated, please use method buildScheme instead.
   * @return The buildable object.
   */
  @Deprecated
  public StringMatch getScheme();
  public StringMatch buildScheme();
  public A withScheme(StringMatch scheme);
  public Boolean hasScheme();
  public HTTPMatchRequestFluent.SchemeNested<A> withNewScheme();
  public HTTPMatchRequestFluent.SchemeNested<A> withNewSchemeLike(StringMatch item);
  public HTTPMatchRequestFluent.SchemeNested<A> editScheme();
  public HTTPMatchRequestFluent.SchemeNested<A> editOrNewScheme();
  public HTTPMatchRequestFluent.SchemeNested<A> editOrNewSchemeLike(StringMatch item);
  public A addToSourceLabels(String key,String value);
  public A addToSourceLabels(Map<String,String> map);
  public A removeFromSourceLabels(String key);
  public A removeFromSourceLabels(Map<String,String> map);
  public Map<String,String> getSourceLabels();
  public <K,V>A withSourceLabels(Map<String,String> sourceLabels);
  public Boolean hasSourceLabels();
  public String getSourceNamespace();
  public A withSourceNamespace(String sourceNamespace);
  public Boolean hasSourceNamespace();
  
  /**
   * This method has been deprecated, please use method buildUri instead.
   * @return The buildable object.
   */
  @Deprecated
  public StringMatch getUri();
  public StringMatch buildUri();
  public A withUri(StringMatch uri);
  public Boolean hasUri();
  public HTTPMatchRequestFluent.UriNested<A> withNewUri();
  public HTTPMatchRequestFluent.UriNested<A> withNewUriLike(StringMatch item);
  public HTTPMatchRequestFluent.UriNested<A> editUri();
  public HTTPMatchRequestFluent.UriNested<A> editOrNewUri();
  public HTTPMatchRequestFluent.UriNested<A> editOrNewUriLike(StringMatch item);
  public A addToWithoutHeaders(String key,StringMatch value);
  public A addToWithoutHeaders(Map<String,StringMatch> map);
  public A removeFromWithoutHeaders(String key);
  public A removeFromWithoutHeaders(Map<String,StringMatch> map);
  public Map<String,StringMatch> getWithoutHeaders();
  public <K,V>A withWithoutHeaders(Map<String,StringMatch> withoutHeaders);
  public Boolean hasWithoutHeaders();
  public A withIgnoreUriCase();
  public interface AuthorityNested<N> extends Nested<N>,StringMatchFluent<HTTPMatchRequestFluent.AuthorityNested<N>>{
    public N and();
    public N endAuthority();
    
  }
  public interface MethodNested<N> extends Nested<N>,StringMatchFluent<HTTPMatchRequestFluent.MethodNested<N>>{
    public N and();
    public N endMethod();
    
  }
  public interface SchemeNested<N> extends Nested<N>,StringMatchFluent<HTTPMatchRequestFluent.SchemeNested<N>>{
    public N and();
    public N endScheme();
    
  }
  public interface UriNested<N> extends Nested<N>,StringMatchFluent<HTTPMatchRequestFluent.UriNested<N>>{
    public N and();
    public N endUri();
    
  }
  
}
